import { useCollocation } from "@/modules/collocation";
import { css } from "@linaria/core";
import { IconAddImg } from "@queenjs/icons";
import { Image } from "@queenjs/ui";
import { Button } from "ant-design-vue";
import { useModal } from "queenjs";
import { defineComponent, reactive } from "vue";
import { object } from "vue-types";
import DesignListModel from "./DesignListModel";

export default defineComponent({
  props: {
    value: object().def({}),
    values: object().def({}),
  },
  emits: ["change"],
  setup(props, { emit }) {
    const collocation = useCollocation();
    const modal = useModal();

    // const thumbnail = values.thumbnail ? values.thumbnail : value.thumbnail;

    const state = reactive({
      thumbnail: "thumbnail",
    }) as any;

    const selectDesign = async () => {
      collocation.showModal(<DesignListModel value={props.value} />, {
        title: "选择模型",
        width: "900px",
        onOk: async (v: any) => {
          if (v) {
            state.thumbnail = v.thumbnail;
            emit("change", v);
          }
          modal.cancel();
        },
        onCancel: () => modal.cancel(),
      });
    };
    const changeThumbnail = async () => {
      // let [file] = await ctx.webui.upload.selectAnyFile(false, "image/*");
      // if (file) {
      //   if (!["png", "jpg"].includes(file.ext)) {
      //     ctx.webui.messageError("上传文件格式不正确，仅支持jpg/png格式");
      //     return false;
      //   }
      // }
      // let res = await ctx.webui.upload.uploadFile(file.file, "thumbnail");
      // if (res) {
      //   let { value } = props;
      //   value.thumbnail = res;
      //   state.thumbnail = res;
      //   emit("change", value);
      // }
    };
    return () => {
      const { thumbnail } = state;
      return (
        <div>
          {thumbnail && thumbnail.url ? (
            <div class={DesignSelect}>
              <Image src={thumbnail.url} size={98} />
              <div class={"thumbnail_cover"}>
                <Button type="text" onClick={selectDesign}>
                  更换款式
                </Button>
                <Button type="text" onClick={changeThumbnail}>
                  更换封面
                </Button>
              </div>
            </div>
          ) : (
            <div class={DesignSelect} onClick={selectDesign}>
              <IconAddImg class="text-30px mb-10px" />
              <span class="text-12px">点击选择</span>
            </div>
          )}
        </div>
      );
    };
  },
});

const DesignSelect = css`
  position: relative;
  width: 98px;
  height: 98px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  padding: 10px;
  border-radius: 4px;
  color: @inf-primary-color;
  background: #eef1fe;
  cursor: pointer;
  img {
    width: 100%;
    height: 100%;
    object-fit: contain;
  }

  &:hover {
    .thumbnail_cover {
      display: flex;
      flex-flow: column;
      justify-content: center;
    }
  }
  .thumbnail_cover {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    padding: 10px;
    display: none;
    background-color: rgba(0, 0, 0, 0.2);
    button.ant-btn {
      padding: 0;
      &:last-child {
        margin-top: 10px;
      }
    }
  }
`;
