import { useCollocation } from "@/modules/collocation";
import { css } from "@linaria/core";
import { Button, Space, Table } from "ant-design-vue";
import { defineComponent, onMounted } from "vue";
import { Image } from "@queenjs/ui";
import OperationModal from "./components/OperationModal";
import { queenApi } from "queenjs";

export default defineComponent({
  setup() {
    const collocation = useCollocation();

    const columns = [
      {
        title: "款式图片",
        dataIndex: "thumbnail",
        key: "thumbnail",
        customRender: ({ text }: any) => (
          <Image class="thumbnail" src={text?.url} size={120} />
        ),
      },
      {
        title: "款式名称",
        dataIndex: "name",
        key: "name",
        width: 200,
      },
      {
        title: "款式编号",
        dataIndex: "code",
        key: "code",
      },
      {
        title: "款式类别",
        dataIndex: "category",
        key: "category",
      },
      {
        title: "价格(元)",
        dataIndex: "price",
        key: "price",
        customRender: ({ text }: any) => (text / 100 || 0).toFixed(2),
      },
      {
        title: "操作",
        key: "action",
        dataIndex: "action",
        customRender: ({ record }: any) => {
          return (
            <Space>
              <Button type="link" onClick={() => showEdit(record)}>
                编辑
              </Button>
              <Button
                type="link"
                onClick={() => {
                  queenApi.router.push(`/design/edit/${record._id}`);
                  // ctx.comm.mallJumpStyleEditor(record._id);
                }}
              >
                定制内容
              </Button>
              <Button type="text" danger onClick={() => delDesign(record)}>
                删除
              </Button>
            </Space>
          );
        },
      },
    ];

    onMounted(() => {
      // ctx.design.DesignList.loadPage(1, 20);
      // ctx.design.SizeList.loadPage(1, 1000);
    });

    const showAddDesign = async () => {
      const values: any = await collocation.showModal(<OperationModal />, {
        title: "添加可定制款式",
        width: "500px",
      });
      if (!values) return;
      values.thumbnail = values.scenePack.thumbnail;
      // values.price = parseInt(values.price * 100 + "");
      // let res = await ctx.design.actions.addDesign(values);
    };

    const showEdit = async (record: any) => {
      // let item = await ctx.design.actions.getDesignDTL(record._id);
      // if (!item) return false;
      // item.price = (item.price / 100).toFixed(2);
      const values: any = await collocation.showModal(<OperationModal />, {
        title: "编辑可定制款式",
        width: "500px",
      });
      // if (!values) return;
      // values.thumbnail = values.scenePack.thumbnail;
      // values.price = parseInt(values.price * 100 + "");
      // let res = await ctx.design.actions.updateDesign(values);
    };

    const delDesign = (item: any) => {
      collocation.actions.delDesign(item);
    };

    return () => {
      const dataSource: any = [{ name: "456", _id: "122" }];
      return (
        <div class={DesignStyle}>
          <div class="mb-20px table_header">
            <h3 class="font-bold">款式列表</h3>
            <Button type="primary" onClick={showAddDesign}>
              添加+
            </Button>
          </div>
          <Table
            size="small"
            columns={columns}
            dataSource={dataSource}
            rowKey={(record) => record._id}
            pagination={{
              size: "default",
              // pageSize: ctx.design.DesignList.state.size,
              // current: ctx.design.DesignList.state.page,
              // total: ctx.design.DesignList.state.total,
              // onChange: (p) => ctx.design.DesignList.loadPage(p),
            }}
          />
        </div>
      );
    };
  },
});

const DesignStyle = css`
  padding: 20px;
  .table_header {
    display: flex;
    align-items: center;
    justify-content: space-between;
  }
  .ant-table-thead > tr > th,
  .ant-table-tbody > tr > td {
    text-align: center;
  }
  .thumbnail {
    width: 120px;
    object-fit: contain;
  }
`;
